"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class TpuNodeXSchedulingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PREEMPTIBLE_FIELD_NUMBER: builtins.int
    preemptible: builtins.bool
    def __init__(
        self,
        *,
        preemptible: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["preemptible", b"preemptible"]) -> None: ...

global___TpuNodeXSchedulingConfig = TpuNodeXSchedulingConfig

@typing_extensions.final
class TpuNodeXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___TpuNodeXTimeouts = TpuNodeXTimeouts

@typing_extensions.final
class TpuNode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class NetworkEndpointsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ACCELERATOR_TYPE_FIELD_NUMBER: builtins.int
    CIDR_BLOCK_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    NETWORK_ENDPOINTS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    TENSORFLOW_VERSION_FIELD_NUMBER: builtins.int
    USE_SERVICE_NETWORKING_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    SCHEDULING_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    accelerator_type: builtins.str
    cidr_block: builtins.str
    description: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    network: builtins.str
    @property
    def network_endpoints(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    project: builtins.str
    service_account: builtins.str
    tensorflow_version: builtins.str
    use_service_networking: builtins.bool
    zone: builtins.str
    @property
    def scheduling_config(self) -> global___TpuNodeXSchedulingConfig: ...
    @property
    def timeouts(self) -> global___TpuNodeXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        accelerator_type: builtins.str = ...,
        cidr_block: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        network_endpoints: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        project: builtins.str = ...,
        service_account: builtins.str = ...,
        tensorflow_version: builtins.str = ...,
        use_service_networking: builtins.bool = ...,
        zone: builtins.str = ...,
        scheduling_config: global___TpuNodeXSchedulingConfig | None = ...,
        timeouts: global___TpuNodeXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "scheduling_config", b"scheduling_config", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accelerator_type", b"accelerator_type", "cidr_block", b"cidr_block", "description", b"description", "id", b"id", "labels", b"labels", "name", b"name", "network", b"network", "network_endpoints", b"network_endpoints", "project", b"project", "resource_info", b"resource_info", "scheduling_config", b"scheduling_config", "service_account", b"service_account", "tensorflow_version", b"tensorflow_version", "timeouts", b"timeouts", "use_service_networking", b"use_service_networking", "zone", b"zone"]) -> None: ...

global___TpuNode = TpuNode



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_notebooks.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17gcp/gcp_notebooks.proto\x12\x19oak9.tython.gcp.notebooks\x1a\x13shared/shared.proto\"F\n#NotebooksEnvironmentXContainerImage\x12\x12\n\nrepository\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"O\n\x1dNotebooksEnvironmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"Y\n\x1cNotebooksEnvironmentXVmImage\x12\x14\n\x0cimage_family\x18\x01 \x01(\t\x12\x12\n\nimage_name\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\"\xd9\x03\n\x14NotebooksEnvironment\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x1b\n\x13post_startup_script\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12W\n\x0f\x63ontainer_image\x18\t \x01(\x0b\x32>.oak9.tython.gcp.notebooks.NotebooksEnvironmentXContainerImage\x12J\n\x08timeouts\x18\n \x01(\x0b\x32\x38.oak9.tython.gcp.notebooks.NotebooksEnvironmentXTimeouts\x12I\n\x08vm_image\x18\x0b \x01(\x0b\x32\x37.oak9.tython.gcp.notebooks.NotebooksEnvironmentXVmImage\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"G\n#NotebooksInstanceXAcceleratorConfig\x12\x12\n\ncore_count\x18\x01 \x01(\x01\x12\x0c\n\x04type\x18\x02 \x01(\t\"C\n NotebooksInstanceXContainerImage\x12\x12\n\nrepository\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"f\n%NotebooksInstanceXReservationAffinity\x12 \n\x18\x63onsume_reservation_type\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\"\x80\x01\n(NotebooksInstanceXShieldedInstanceConfig\x12#\n\x1b\x65nable_integrity_monitoring\x18\x01 \x01(\x08\x12\x1a\n\x12\x65nable_secure_boot\x18\x02 \x01(\x08\x12\x13\n\x0b\x65nable_vtpm\x18\x03 \x01(\x08\"L\n\x1aNotebooksInstanceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"V\n\x19NotebooksInstanceXVmImage\x12\x14\n\x0cimage_family\x18\x01 \x01(\t\x12\x12\n\nimage_name\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\"\xb5\x0b\n\x11NotebooksInstance\x12\x19\n\x11\x62oot_disk_size_gb\x18\x01 \x01(\x01\x12\x16\n\x0e\x62oot_disk_type\x18\x02 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x03 \x01(\t\x12\x1e\n\x16\x63ustom_gpu_driver_path\x18\x04 \x01(\t\x12\x19\n\x11\x64\x61ta_disk_size_gb\x18\x05 \x01(\x01\x12\x16\n\x0e\x64\x61ta_disk_type\x18\x06 \x01(\t\x12\x17\n\x0f\x64isk_encryption\x18\x07 \x01(\t\x12\n\n\x02id\x18\x08 \x01(\t\x12\x1a\n\x12install_gpu_driver\x18\t \x01(\x08\x12\x17\n\x0finstance_owners\x18\n \x03(\t\x12\x0f\n\x07kms_key\x18\x0b \x01(\t\x12H\n\x06labels\x18\x0c \x03(\x0b\x32\x38.oak9.tython.gcp.notebooks.NotebooksInstance.LabelsEntry\x12\x10\n\x08location\x18\r \x01(\t\x12\x14\n\x0cmachine_type\x18\x0e \x01(\t\x12L\n\x08metadata\x18\x0f \x03(\x0b\x32:.oak9.tython.gcp.notebooks.NotebooksInstance.MetadataEntry\x12\x0c\n\x04name\x18\x10 \x01(\t\x12\x0f\n\x07network\x18\x11 \x01(\t\x12\x10\n\x08nic_type\x18\x12 \x01(\t\x12\x17\n\x0fno_proxy_access\x18\x13 \x01(\x08\x12\x14\n\x0cno_public_ip\x18\x14 \x01(\x08\x12\x1b\n\x13no_remove_data_disk\x18\x15 \x01(\x08\x12\x1b\n\x13post_startup_script\x18\x16 \x01(\t\x12\x0f\n\x07project\x18\x17 \x01(\t\x12\x11\n\tproxy_uri\x18\x18 \x01(\t\x12\x17\n\x0fservice_account\x18\x19 \x01(\t\x12\x1e\n\x16service_account_scopes\x18\x1a \x03(\t\x12\r\n\x05state\x18\x1b \x01(\t\x12\x0e\n\x06subnet\x18\x1c \x01(\t\x12\x0c\n\x04tags\x18\x1d \x03(\t\x12\x13\n\x0bupdate_time\x18\x1e \x01(\t\x12Z\n\x12\x61\x63\x63\x65lerator_config\x18\x1f \x01(\x0b\x32>.oak9.tython.gcp.notebooks.NotebooksInstanceXAcceleratorConfig\x12T\n\x0f\x63ontainer_image\x18  \x01(\x0b\x32;.oak9.tython.gcp.notebooks.NotebooksInstanceXContainerImage\x12^\n\x14reservation_affinity\x18! \x01(\x0b\x32@.oak9.tython.gcp.notebooks.NotebooksInstanceXReservationAffinity\x12\x65\n\x18shielded_instance_config\x18\" \x01(\x0b\x32\x43.oak9.tython.gcp.notebooks.NotebooksInstanceXShieldedInstanceConfig\x12G\n\x08timeouts\x18# \x01(\x0b\x32\x35.oak9.tython.gcp.notebooks.NotebooksInstanceXTimeouts\x12\x46\n\x08vm_image\x18$ \x01(\x0b\x32\x34.oak9.tython.gcp.notebooks.NotebooksInstanceXVmImage\x12\x37\n\rresource_info\x18% \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"_\n%NotebooksInstanceIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x9e\x02\n\x1bNotebooksInstanceIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rinstance_name\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0f\n\x07members\x18\x05 \x03(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12S\n\tcondition\x18\x08 \x01(\x0b\x32@.oak9.tython.gcp.notebooks.NotebooksInstanceIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"^\n$NotebooksInstanceIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x9b\x02\n\x1aNotebooksInstanceIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rinstance_name\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0e\n\x06member\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12R\n\tcondition\x18\x08 \x01(\x0b\x32?.oak9.tython.gcp.notebooks.NotebooksInstanceIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbe\x01\n\x1aNotebooksInstanceIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x15\n\rinstance_name\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"L\n\x1aNotebooksLocationXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd3\x01\n\x11NotebooksLocation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x11\n\tself_link\x18\x04 \x01(\t\x12G\n\x08timeouts\x18\x05 \x01(\x0b\x32\x35.oak9.tython.gcp.notebooks.NotebooksLocationXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"^\n\x1dNotebooksRuntimeXAccessConfig\x12\x13\n\x0b\x61\x63\x63\x65ss_type\x18\x01 \x01(\t\x12\x11\n\tproxy_uri\x18\x02 \x01(\t\x12\x15\n\rruntime_owner\x18\x03 \x01(\t\"J\n\'NotebooksRuntimeXSoftwareConfigXKernels\x12\x12\n\nrepository\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"\x85\x03\n\x1fNotebooksRuntimeXSoftwareConfig\x12\x1e\n\x16\x63ustom_gpu_driver_path\x18\x01 \x01(\t\x12 \n\x18\x65nable_health_monitoring\x18\x02 \x01(\x08\x12\x15\n\ridle_shutdown\x18\x03 \x01(\x08\x12\x1d\n\x15idle_shutdown_timeout\x18\x04 \x01(\x01\x12\x1a\n\x12install_gpu_driver\x18\x05 \x01(\x08\x12!\n\x19notebook_upgrade_schedule\x18\x06 \x01(\t\x12\x1b\n\x13post_startup_script\x18\x07 \x01(\t\x12$\n\x1cpost_startup_script_behavior\x18\x08 \x01(\t\x12\x13\n\x0bupgradeable\x18\t \x01(\x08\x12S\n\x07kernels\x18\n \x03(\x0b\x32\x42.oak9.tython.gcp.notebooks.NotebooksRuntimeXSoftwareConfigXKernels\"K\n\x19NotebooksRuntimeXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"j\nFNotebooksRuntimeXVirtualMachineXVirtualMachineConfigXAcceleratorConfig\x12\x12\n\ncore_count\x18\x01 \x01(\x01\x12\x0c\n\x04type\x18\x02 \x01(\t\"g\nDNotebooksRuntimeXVirtualMachineXVirtualMachineConfigXContainerImages\x12\x12\n\nrepository\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"\xd8\x02\nNNotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDiskXInitializeParams\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x11\n\tdisk_name\x18\x02 \x01(\t\x12\x14\n\x0c\x64isk_size_gb\x18\x03 \x01(\x01\x12\x11\n\tdisk_type\x18\x04 \x01(\t\x12\x85\x01\n\x06labels\x18\x05 \x03(\x0b\x32u.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDiskXInitializeParams.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x87\x03\n=NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDisk\x12\x13\n\x0b\x61uto_delete\x18\x01 \x01(\x08\x12\x0c\n\x04\x62oot\x18\x02 \x01(\x08\x12\x13\n\x0b\x64\x65vice_name\x18\x03 \x01(\t\x12\x19\n\x11guest_os_features\x18\x04 \x03(\t\x12\r\n\x05index\x18\x05 \x01(\x01\x12\x11\n\tinterface\x18\x06 \x01(\t\x12\x0c\n\x04kind\x18\x07 \x01(\t\x12\x10\n\x08licenses\x18\x08 \x03(\t\x12\x0c\n\x04mode\x18\t \x01(\t\x12\x0e\n\x06source\x18\n \x01(\t\x12\x0c\n\x04type\x18\x0b \x01(\t\x12\x84\x01\n\x11initialize_params\x18\x0c \x01(\x0b\x32i.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDiskXInitializeParams\"X\nENotebooksRuntimeXVirtualMachineXVirtualMachineConfigXEncryptionConfig\x12\x0f\n\x07kms_key\x18\x01 \x01(\t\"\xa3\x01\nKNotebooksRuntimeXVirtualMachineXVirtualMachineConfigXShieldedInstanceConfig\x12#\n\x1b\x65nable_integrity_monitoring\x18\x01 \x01(\x08\x12\x1a\n\x12\x65nable_secure_boot\x18\x02 \x01(\x08\x12\x13\n\x0b\x65nable_vtpm\x18\x03 \x01(\x08\"\xb5\n\n4NotebooksRuntimeXVirtualMachineXVirtualMachineConfig\x12~\n\x10guest_attributes\x18\x01 \x03(\x0b\x32\x64.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfig.GuestAttributesEntry\x12\x18\n\x10internal_ip_only\x18\x02 \x01(\x08\x12k\n\x06labels\x18\x03 \x03(\x0b\x32[.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfig.LabelsEntry\x12\x14\n\x0cmachine_type\x18\x04 \x01(\t\x12o\n\x08metadata\x18\x05 \x03(\x0b\x32].oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfig.MetadataEntry\x12\x0f\n\x07network\x18\x06 \x01(\t\x12\x10\n\x08nic_type\x18\x07 \x01(\t\x12\x19\n\x11reserved_ip_range\x18\x08 \x01(\t\x12\x0e\n\x06subnet\x18\t \x01(\t\x12\x0c\n\x04tags\x18\n \x03(\t\x12\x0c\n\x04zone\x18\x0b \x01(\t\x12}\n\x12\x61\x63\x63\x65lerator_config\x18\x0c \x01(\x0b\x32\x61.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXAcceleratorConfig\x12y\n\x10\x63ontainer_images\x18\r \x03(\x0b\x32_.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXContainerImages\x12k\n\tdata_disk\x18\x0e \x01(\x0b\x32X.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXDataDisk\x12{\n\x11\x65ncryption_config\x18\x0f \x01(\x0b\x32`.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXEncryptionConfig\x12\x88\x01\n\x18shielded_instance_config\x18\x10 \x01(\x0b\x32\x66.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfigXShieldedInstanceConfig\x1a\x36\n\x14GuestAttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbe\x01\n\x1fNotebooksRuntimeXVirtualMachine\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x15\n\rinstance_name\x18\x02 \x01(\t\x12o\n\x16virtual_machine_config\x18\x03 \x01(\x0b\x32O.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachineXVirtualMachineConfig\"\xeb\x04\n\x10NotebooksRuntime\x12\x14\n\x0chealth_state\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12I\n\x07metrics\x18\x04 \x03(\x0b\x32\x38.oak9.tython.gcp.notebooks.NotebooksRuntime.MetricsEntry\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\r\n\x05state\x18\x07 \x01(\t\x12O\n\raccess_config\x18\x08 \x01(\x0b\x32\x38.oak9.tython.gcp.notebooks.NotebooksRuntimeXAccessConfig\x12S\n\x0fsoftware_config\x18\t \x01(\x0b\x32:.oak9.tython.gcp.notebooks.NotebooksRuntimeXSoftwareConfig\x12\x46\n\x08timeouts\x18\n \x01(\x0b\x32\x34.oak9.tython.gcp.notebooks.NotebooksRuntimeXTimeouts\x12S\n\x0fvirtual_machine\x18\x0b \x01(\x0b\x32:.oak9.tython.gcp.notebooks.NotebooksRuntimeXVirtualMachine\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"^\n$NotebooksRuntimeIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x9b\x02\n\x1aNotebooksRuntimeIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x14\n\x0cruntime_name\x18\x07 \x01(\t\x12R\n\tcondition\x18\x08 \x01(\x0b\x32?.oak9.tython.gcp.notebooks.NotebooksRuntimeIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"]\n#NotebooksRuntimeIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x98\x02\n\x19NotebooksRuntimeIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04role\x18\x06 \x01(\t\x12\x14\n\x0cruntime_name\x18\x07 \x01(\t\x12Q\n\tcondition\x18\x08 \x01(\x0b\x32>.oak9.tython.gcp.notebooks.NotebooksRuntimeIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbc\x01\n\x19NotebooksRuntimeIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x14\n\x0cruntime_name\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_notebooks_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NOTEBOOKSINSTANCE_LABELSENTRY._options = None
  _NOTEBOOKSINSTANCE_LABELSENTRY._serialized_options = b'8\001'
  _NOTEBOOKSINSTANCE_METADATAENTRY._options = None
  _NOTEBOOKSINSTANCE_METADATAENTRY._serialized_options = b'8\001'
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXDATADISKXINITIALIZEPARAMS_LABELSENTRY._options = None
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXDATADISKXINITIALIZEPARAMS_LABELSENTRY._serialized_options = b'8\001'
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_GUESTATTRIBUTESENTRY._options = None
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_GUESTATTRIBUTESENTRY._serialized_options = b'8\001'
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_LABELSENTRY._options = None
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_LABELSENTRY._serialized_options = b'8\001'
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_METADATAENTRY._options = None
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_METADATAENTRY._serialized_options = b'8\001'
  _NOTEBOOKSRUNTIME_METRICSENTRY._options = None
  _NOTEBOOKSRUNTIME_METRICSENTRY._serialized_options = b'8\001'
  _NOTEBOOKSENVIRONMENTXCONTAINERIMAGE._serialized_start=75
  _NOTEBOOKSENVIRONMENTXCONTAINERIMAGE._serialized_end=145
  _NOTEBOOKSENVIRONMENTXTIMEOUTS._serialized_start=147
  _NOTEBOOKSENVIRONMENTXTIMEOUTS._serialized_end=226
  _NOTEBOOKSENVIRONMENTXVMIMAGE._serialized_start=228
  _NOTEBOOKSENVIRONMENTXVMIMAGE._serialized_end=317
  _NOTEBOOKSENVIRONMENT._serialized_start=320
  _NOTEBOOKSENVIRONMENT._serialized_end=793
  _NOTEBOOKSINSTANCEXACCELERATORCONFIG._serialized_start=795
  _NOTEBOOKSINSTANCEXACCELERATORCONFIG._serialized_end=866
  _NOTEBOOKSINSTANCEXCONTAINERIMAGE._serialized_start=868
  _NOTEBOOKSINSTANCEXCONTAINERIMAGE._serialized_end=935
  _NOTEBOOKSINSTANCEXRESERVATIONAFFINITY._serialized_start=937
  _NOTEBOOKSINSTANCEXRESERVATIONAFFINITY._serialized_end=1039
  _NOTEBOOKSINSTANCEXSHIELDEDINSTANCECONFIG._serialized_start=1042
  _NOTEBOOKSINSTANCEXSHIELDEDINSTANCECONFIG._serialized_end=1170
  _NOTEBOOKSINSTANCEXTIMEOUTS._serialized_start=1172
  _NOTEBOOKSINSTANCEXTIMEOUTS._serialized_end=1248
  _NOTEBOOKSINSTANCEXVMIMAGE._serialized_start=1250
  _NOTEBOOKSINSTANCEXVMIMAGE._serialized_end=1336
  _NOTEBOOKSINSTANCE._serialized_start=1339
  _NOTEBOOKSINSTANCE._serialized_end=2800
  _NOTEBOOKSINSTANCE_LABELSENTRY._serialized_start=2706
  _NOTEBOOKSINSTANCE_LABELSENTRY._serialized_end=2751
  _NOTEBOOKSINSTANCE_METADATAENTRY._serialized_start=2753
  _NOTEBOOKSINSTANCE_METADATAENTRY._serialized_end=2800
  _NOTEBOOKSINSTANCEIAMBINDINGXCONDITION._serialized_start=2802
  _NOTEBOOKSINSTANCEIAMBINDINGXCONDITION._serialized_end=2897
  _NOTEBOOKSINSTANCEIAMBINDING._serialized_start=2900
  _NOTEBOOKSINSTANCEIAMBINDING._serialized_end=3186
  _NOTEBOOKSINSTANCEIAMMEMBERXCONDITION._serialized_start=3188
  _NOTEBOOKSINSTANCEIAMMEMBERXCONDITION._serialized_end=3282
  _NOTEBOOKSINSTANCEIAMMEMBER._serialized_start=3285
  _NOTEBOOKSINSTANCEIAMMEMBER._serialized_end=3568
  _NOTEBOOKSINSTANCEIAMPOLICY._serialized_start=3571
  _NOTEBOOKSINSTANCEIAMPOLICY._serialized_end=3761
  _NOTEBOOKSLOCATIONXTIMEOUTS._serialized_start=3763
  _NOTEBOOKSLOCATIONXTIMEOUTS._serialized_end=3839
  _NOTEBOOKSLOCATION._serialized_start=3842
  _NOTEBOOKSLOCATION._serialized_end=4053
  _NOTEBOOKSRUNTIMEXACCESSCONFIG._serialized_start=4055
  _NOTEBOOKSRUNTIMEXACCESSCONFIG._serialized_end=4149
  _NOTEBOOKSRUNTIMEXSOFTWARECONFIGXKERNELS._serialized_start=4151
  _NOTEBOOKSRUNTIMEXSOFTWARECONFIGXKERNELS._serialized_end=4225
  _NOTEBOOKSRUNTIMEXSOFTWARECONFIG._serialized_start=4228
  _NOTEBOOKSRUNTIMEXSOFTWARECONFIG._serialized_end=4617
  _NOTEBOOKSRUNTIMEXTIMEOUTS._serialized_start=4619
  _NOTEBOOKSRUNTIMEXTIMEOUTS._serialized_end=4694
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXACCELERATORCONFIG._serialized_start=4696
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXACCELERATORCONFIG._serialized_end=4802
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXCONTAINERIMAGES._serialized_start=4804
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXCONTAINERIMAGES._serialized_end=4907
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXDATADISKXINITIALIZEPARAMS._serialized_start=4910
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXDATADISKXINITIALIZEPARAMS._serialized_end=5254
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXDATADISKXINITIALIZEPARAMS_LABELSENTRY._serialized_start=2706
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXDATADISKXINITIALIZEPARAMS_LABELSENTRY._serialized_end=2751
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXDATADISK._serialized_start=5257
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXDATADISK._serialized_end=5648
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXENCRYPTIONCONFIG._serialized_start=5650
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXENCRYPTIONCONFIG._serialized_end=5738
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXSHIELDEDINSTANCECONFIG._serialized_start=5741
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIGXSHIELDEDINSTANCECONFIG._serialized_end=5904
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG._serialized_start=5907
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG._serialized_end=7240
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_GUESTATTRIBUTESENTRY._serialized_start=7090
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_GUESTATTRIBUTESENTRY._serialized_end=7144
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_LABELSENTRY._serialized_start=2706
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_LABELSENTRY._serialized_end=2751
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_METADATAENTRY._serialized_start=2753
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINEXVIRTUALMACHINECONFIG_METADATAENTRY._serialized_end=2800
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINE._serialized_start=7243
  _NOTEBOOKSRUNTIMEXVIRTUALMACHINE._serialized_end=7433
  _NOTEBOOKSRUNTIME._serialized_start=7436
  _NOTEBOOKSRUNTIME._serialized_end=8055
  _NOTEBOOKSRUNTIME_METRICSENTRY._serialized_start=8009
  _NOTEBOOKSRUNTIME_METRICSENTRY._serialized_end=8055
  _NOTEBOOKSRUNTIMEIAMBINDINGXCONDITION._serialized_start=8057
  _NOTEBOOKSRUNTIMEIAMBINDINGXCONDITION._serialized_end=8151
  _NOTEBOOKSRUNTIMEIAMBINDING._serialized_start=8154
  _NOTEBOOKSRUNTIMEIAMBINDING._serialized_end=8437
  _NOTEBOOKSRUNTIMEIAMMEMBERXCONDITION._serialized_start=8439
  _NOTEBOOKSRUNTIMEIAMMEMBERXCONDITION._serialized_end=8532
  _NOTEBOOKSRUNTIMEIAMMEMBER._serialized_start=8535
  _NOTEBOOKSRUNTIMEIAMMEMBER._serialized_end=8815
  _NOTEBOOKSRUNTIMEIAMPOLICY._serialized_start=8818
  _NOTEBOOKSRUNTIMEIAMPOLICY._serialized_end=9006
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MlEngineModelXDefaultVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___MlEngineModelXDefaultVersion = MlEngineModelXDefaultVersion

@typing_extensions.final
class MlEngineModelXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___MlEngineModelXTimeouts = MlEngineModelXTimeouts

@typing_extensions.final
class MlEngineModel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ONLINE_PREDICTION_CONSOLE_LOGGING_FIELD_NUMBER: builtins.int
    ONLINE_PREDICTION_LOGGING_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGIONS_FIELD_NUMBER: builtins.int
    DEFAULT_VERSION_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    online_prediction_console_logging: builtins.bool
    online_prediction_logging: builtins.bool
    project: builtins.str
    @property
    def regions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def default_version(self) -> global___MlEngineModelXDefaultVersion: ...
    @property
    def timeouts(self) -> global___MlEngineModelXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        online_prediction_console_logging: builtins.bool = ...,
        online_prediction_logging: builtins.bool = ...,
        project: builtins.str = ...,
        regions: collections.abc.Iterable[builtins.str] | None = ...,
        default_version: global___MlEngineModelXDefaultVersion | None = ...,
        timeouts: global___MlEngineModelXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_version", b"default_version", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_version", b"default_version", "description", b"description", "id", b"id", "labels", b"labels", "name", b"name", "online_prediction_console_logging", b"online_prediction_console_logging", "online_prediction_logging", b"online_prediction_logging", "project", b"project", "regions", b"regions", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___MlEngineModel = MlEngineModel



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputePerInstanceConfigXPreservedStateXDisk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DELETE_RULE_FIELD_NUMBER: builtins.int
    DEVICE_NAME_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    delete_rule: builtins.str
    device_name: builtins.str
    mode: builtins.str
    source: builtins.str
    def __init__(
        self,
        *,
        delete_rule: builtins.str = ...,
        device_name: builtins.str = ...,
        mode: builtins.str = ...,
        source: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_rule", b"delete_rule", "device_name", b"device_name", "mode", b"mode", "source", b"source"]) -> None: ...

global___ComputePerInstanceConfigXPreservedStateXDisk = ComputePerInstanceConfigXPreservedStateXDisk

@typing_extensions.final
class ComputePerInstanceConfigXPreservedState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class MetadataEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    METADATA_FIELD_NUMBER: builtins.int
    DISK_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def disk(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputePerInstanceConfigXPreservedStateXDisk]: ...
    def __init__(
        self,
        *,
        metadata: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        disk: collections.abc.Iterable[global___ComputePerInstanceConfigXPreservedStateXDisk] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk", b"disk", "metadata", b"metadata"]) -> None: ...

global___ComputePerInstanceConfigXPreservedState = ComputePerInstanceConfigXPreservedState

@typing_extensions.final
class ComputePerInstanceConfigXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputePerInstanceConfigXTimeouts = ComputePerInstanceConfigXTimeouts

@typing_extensions.final
class ComputePerInstanceConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    INSTANCE_GROUP_MANAGER_FIELD_NUMBER: builtins.int
    MINIMAL_ACTION_FIELD_NUMBER: builtins.int
    MOST_DISRUPTIVE_ALLOWED_ACTION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REMOVE_INSTANCE_STATE_ON_DESTROY_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    PRESERVED_STATE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    instance_group_manager: builtins.str
    minimal_action: builtins.str
    most_disruptive_allowed_action: builtins.str
    name: builtins.str
    project: builtins.str
    remove_instance_state_on_destroy: builtins.bool
    zone: builtins.str
    @property
    def preserved_state(self) -> global___ComputePerInstanceConfigXPreservedState: ...
    @property
    def timeouts(self) -> global___ComputePerInstanceConfigXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        instance_group_manager: builtins.str = ...,
        minimal_action: builtins.str = ...,
        most_disruptive_allowed_action: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        remove_instance_state_on_destroy: builtins.bool = ...,
        zone: builtins.str = ...,
        preserved_state: global___ComputePerInstanceConfigXPreservedState | None = ...,
        timeouts: global___ComputePerInstanceConfigXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["preserved_state", b"preserved_state", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "instance_group_manager", b"instance_group_manager", "minimal_action", b"minimal_action", "most_disruptive_allowed_action", b"most_disruptive_allowed_action", "name", b"name", "preserved_state", b"preserved_state", "project", b"project", "remove_instance_state_on_destroy", b"remove_instance_state_on_destroy", "resource_info", b"resource_info", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputePerInstanceConfig = ComputePerInstanceConfig



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.api.core.v1_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class HTTPIngressPath(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKEND_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    PATH_TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def backend(self) -> global___IngressBackend: ...
    path: builtins.str
    path_type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        backend: global___IngressBackend | None = ...,
        path: builtins.str = ...,
        path_type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["backend", b"backend", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["backend", b"backend", "path", b"path", "path_type", b"path_type", "resource_info", b"resource_info"]) -> None: ...

global___HTTPIngressPath = HTTPIngressPath

@typing_extensions.final
class HTTPIngressRuleValue(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PATHS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def paths(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HTTPIngressPath]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        paths: collections.abc.Iterable[global___HTTPIngressPath] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["paths", b"paths", "resource_info", b"resource_info"]) -> None: ...

global___HTTPIngressRuleValue = HTTPIngressRuleValue

@typing_extensions.final
class IPBlock(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CIDR_FIELD_NUMBER: builtins.int
    EXCEPT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    cidr: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cidr: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cidr", b"cidr", "except", b"except", "resource_info", b"resource_info"]) -> None: ...

global___IPBlock = IPBlock

@typing_extensions.final
class Ingress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___IngressSpec: ...
    @property
    def status(self) -> global___IngressStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___IngressSpec | None = ...,
        status: global___IngressStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___Ingress = Ingress

@typing_extensions.final
class IngressBackend(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def resource(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.TypedLocalObjectReference: ...
    @property
    def service(self) -> global___IngressServiceBackend: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        resource: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.TypedLocalObjectReference | None = ...,
        service: global___IngressServiceBackend | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource", b"resource", "resource_info", b"resource_info", "service", b"service"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource", b"resource", "resource_info", b"resource_info", "service", b"service"]) -> None: ...

global___IngressBackend = IngressBackend

@typing_extensions.final
class IngressClass(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___IngressClassSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___IngressClassSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> None: ...

global___IngressClass = IngressClass

@typing_extensions.final
class IngressClassList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IngressClass]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___IngressClass] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___IngressClassList = IngressClassList

@typing_extensions.final
class IngressClassParametersReference(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GROUP_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    SCOPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_group: builtins.str
    kind: builtins.str
    name: builtins.str
    namespace: builtins.str
    scope: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_group: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        scope: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_group", b"api_group", "kind", b"kind", "name", b"name", "namespace", b"namespace", "resource_info", b"resource_info", "scope", b"scope"]) -> None: ...

global___IngressClassParametersReference = IngressClassParametersReference

@typing_extensions.final
class IngressClassSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTROLLER_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    controller: builtins.str
    @property
    def parameters(self) -> global___IngressClassParametersReference: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        controller: builtins.str = ...,
        parameters: global___IngressClassParametersReference | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["parameters", b"parameters", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["controller", b"controller", "parameters", b"parameters", "resource_info", b"resource_info"]) -> None: ...

global___IngressClassSpec = IngressClassSpec

@typing_extensions.final
class IngressList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Ingress]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___Ingress] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___IngressList = IngressList

@typing_extensions.final
class IngressLoadBalancerIngress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTNAME_FIELD_NUMBER: builtins.int
    IP_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    hostname: builtins.str
    ip: builtins.str
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IngressPortStatus]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        hostname: builtins.str = ...,
        ip: builtins.str = ...,
        ports: collections.abc.Iterable[global___IngressPortStatus] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hostname", b"hostname", "ip", b"ip", "ports", b"ports", "resource_info", b"resource_info"]) -> None: ...

global___IngressLoadBalancerIngress = IngressLoadBalancerIngress

@typing_extensions.final
class IngressLoadBalancerStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INGRESS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def ingress(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IngressLoadBalancerIngress]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ingress: collections.abc.Iterable[global___IngressLoadBalancerIngress] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ingress", b"ingress", "resource_info", b"resource_info"]) -> None: ...

global___IngressLoadBalancerStatus = IngressLoadBalancerStatus

@typing_extensions.final
class IngressPortStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ERROR_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    error: builtins.str
    port: builtins.int
    protocol: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        error: builtins.str = ...,
        port: builtins.int = ...,
        protocol: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["error", b"error", "port", b"port", "protocol", b"protocol", "resource_info", b"resource_info"]) -> None: ...

global___IngressPortStatus = IngressPortStatus

@typing_extensions.final
class IngressRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    HTTP_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    host: builtins.str
    @property
    def http(self) -> global___HTTPIngressRuleValue: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        http: global___HTTPIngressRuleValue | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["http", b"http", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "http", b"http", "resource_info", b"resource_info"]) -> None: ...

global___IngressRule = IngressRule

@typing_extensions.final
class IngressServiceBackend(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    @property
    def port(self) -> global___ServiceBackendPort: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        port: global___ServiceBackendPort | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["port", b"port", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "port", b"port", "resource_info", b"resource_info"]) -> None: ...

global___IngressServiceBackend = IngressServiceBackend

@typing_extensions.final
class IngressSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEFAULT_BACKEND_FIELD_NUMBER: builtins.int
    INGRESS_CLASS_NAME_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    TLS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def default_backend(self) -> global___IngressBackend: ...
    ingress_class_name: builtins.str
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IngressRule]: ...
    @property
    def tls(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___IngressTLS]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        default_backend: global___IngressBackend | None = ...,
        ingress_class_name: builtins.str = ...,
        rules: collections.abc.Iterable[global___IngressRule] | None = ...,
        tls: collections.abc.Iterable[global___IngressTLS] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["default_backend", b"default_backend", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_backend", b"default_backend", "ingress_class_name", b"ingress_class_name", "resource_info", b"resource_info", "rules", b"rules", "tls", b"tls"]) -> None: ...

global___IngressSpec = IngressSpec

@typing_extensions.final
class IngressStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOAD_BALANCER_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def load_balancer(self) -> global___IngressLoadBalancerStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        load_balancer: global___IngressLoadBalancerStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["load_balancer", b"load_balancer", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["load_balancer", b"load_balancer", "resource_info", b"resource_info"]) -> None: ...

global___IngressStatus = IngressStatus

@typing_extensions.final
class IngressTLS(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTS_FIELD_NUMBER: builtins.int
    SECRET_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    secret_name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        hosts: collections.abc.Iterable[builtins.str] | None = ...,
        secret_name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["hosts", b"hosts", "resource_info", b"resource_info", "secret_name", b"secret_name"]) -> None: ...

global___IngressTLS = IngressTLS

@typing_extensions.final
class NetworkPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___NetworkPolicySpec: ...
    @property
    def status(self) -> global___NetworkPolicyStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___NetworkPolicySpec | None = ...,
        status: global___NetworkPolicyStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___NetworkPolicy = NetworkPolicy

@typing_extensions.final
class NetworkPolicyEgressRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORTS_FIELD_NUMBER: builtins.int
    TO_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkPolicyPort]: ...
    @property
    def to(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkPolicyPeer]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ports: collections.abc.Iterable[global___NetworkPolicyPort] | None = ...,
        to: collections.abc.Iterable[global___NetworkPolicyPeer] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ports", b"ports", "resource_info", b"resource_info", "to", b"to"]) -> None: ...

global___NetworkPolicyEgressRule = NetworkPolicyEgressRule

@typing_extensions.final
class NetworkPolicyIngressRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROM_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def ports(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkPolicyPort]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ports: collections.abc.Iterable[global___NetworkPolicyPort] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["from", b"from", "ports", b"ports", "resource_info", b"resource_info"]) -> None: ...

global___NetworkPolicyIngressRule = NetworkPolicyIngressRule

@typing_extensions.final
class NetworkPolicyList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkPolicy]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___NetworkPolicy] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___NetworkPolicyList = NetworkPolicyList

@typing_extensions.final
class NetworkPolicyPeer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IP_BLOCK_FIELD_NUMBER: builtins.int
    NAMESPACE_SELECTOR_FIELD_NUMBER: builtins.int
    POD_SELECTOR_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def ip_block(self) -> global___IPBlock: ...
    @property
    def namespace_selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    @property
    def pod_selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ip_block: global___IPBlock | None = ...,
        namespace_selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        pod_selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ip_block", b"ip_block", "namespace_selector", b"namespace_selector", "pod_selector", b"pod_selector", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ip_block", b"ip_block", "namespace_selector", b"namespace_selector", "pod_selector", b"pod_selector", "resource_info", b"resource_info"]) -> None: ...

global___NetworkPolicyPeer = NetworkPolicyPeer

@typing_extensions.final
class NetworkPolicyPort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    END_PORT_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    end_port: builtins.int
    @property
    def port(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString: ...
    protocol: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        end_port: builtins.int = ...,
        port: kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString | None = ...,
        protocol: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["port", b"port", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_port", b"end_port", "port", b"port", "protocol", b"protocol", "resource_info", b"resource_info"]) -> None: ...

global___NetworkPolicyPort = NetworkPolicyPort

@typing_extensions.final
class NetworkPolicySpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EGRESS_FIELD_NUMBER: builtins.int
    INGRESS_FIELD_NUMBER: builtins.int
    POD_SELECTOR_FIELD_NUMBER: builtins.int
    POLICY_TYPES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def egress(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkPolicyEgressRule]: ...
    @property
    def ingress(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkPolicyIngressRule]: ...
    @property
    def pod_selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    @property
    def policy_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        egress: collections.abc.Iterable[global___NetworkPolicyEgressRule] | None = ...,
        ingress: collections.abc.Iterable[global___NetworkPolicyIngressRule] | None = ...,
        pod_selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        policy_types: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pod_selector", b"pod_selector", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["egress", b"egress", "ingress", b"ingress", "pod_selector", b"pod_selector", "policy_types", b"policy_types", "resource_info", b"resource_info"]) -> None: ...

global___NetworkPolicySpec = NetworkPolicySpec

@typing_extensions.final
class NetworkPolicyStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONDITIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Condition]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        conditions: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Condition] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["conditions", b"conditions", "resource_info", b"resource_info"]) -> None: ...

global___NetworkPolicyStatus = NetworkPolicyStatus

@typing_extensions.final
class ServiceBackendPort(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    NUMBER_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    name: builtins.str
    number: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        number: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "number", b"number", "resource_info", b"resource_info"]) -> None: ...

global___ServiceBackendPort = ServiceBackendPort



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_inspector.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_inspector.proto\x12\x19oak9.tython.aws.inspector\x1a\x13shared/shared.proto\"\x87\x01\n\x10\x41ssessmentTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x61ssessment_target_name\x18\x02 \x01(\t\x12\x1a\n\x12resource_group_arn\x18\x03 \x01(\t\"\xe1\x01\n\tInspector\x12\x46\n\x11\x61ssessment_target\x18\x01 \x03(\x0b\x32+.oak9.tython.aws.inspector.AssessmentTarget\x12J\n\x13\x61ssessment_template\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.inspector.AssessmentTemplate\x12@\n\x0eresource_group\x18\x03 \x03(\x0b\x32(.oak9.tython.aws.inspector.ResourceGroup\"\xfd\x02\n\x12\x41ssessmentTemplate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x61ssessment_target_arn\x18\x02 \x01(\t\x12\x1b\n\x13\x64uration_in_seconds\x18\x03 \x01(\x05\x12 \n\x18\x61ssessment_template_name\x18\x04 \x01(\t\x12\x1a\n\x12rules_package_arns\x18\x05 \x03(\t\x12r\n\x1cuser_attributes_for_findings\x18\x06 \x03(\x0b\x32L.oak9.tython.aws.inspector.AssessmentTemplate.UserAttributesForFindingsEntry\x1a@\n\x1eUserAttributesForFindingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe0\x01\n\rResourceGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\\\n\x13resource_group_tags\x18\x02 \x03(\x0b\x32?.oak9.tython.aws.inspector.ResourceGroup.ResourceGroupTagsEntry\x1a\x38\n\x16ResourceGroupTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_inspector_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ASSESSMENTTEMPLATE_USERATTRIBUTESFORFINDINGSENTRY._options = None
  _ASSESSMENTTEMPLATE_USERATTRIBUTESFORFINDINGSENTRY._serialized_options = b'8\001'
  _RESOURCEGROUP_RESOURCEGROUPTAGSENTRY._options = None
  _RESOURCEGROUP_RESOURCEGROUPTAGSENTRY._serialized_options = b'8\001'
  _ASSESSMENTTARGET._serialized_start=76
  _ASSESSMENTTARGET._serialized_end=211
  _INSPECTOR._serialized_start=214
  _INSPECTOR._serialized_end=439
  _ASSESSMENTTEMPLATE._serialized_start=442
  _ASSESSMENTTEMPLATE._serialized_end=823
  _ASSESSMENTTEMPLATE_USERATTRIBUTESFORFINDINGSENTRY._serialized_start=759
  _ASSESSMENTTEMPLATE_USERATTRIBUTESFORFINDINGSENTRY._serialized_end=823
  _RESOURCEGROUP._serialized_start=826
  _RESOURCEGROUP._serialized_end=1050
  _RESOURCEGROUP_RESOURCEGROUPTAGSENTRY._serialized_start=994
  _RESOURCEGROUP_RESOURCEGROUPTAGSENTRY._serialized_end=1050
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_app.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11gcp/gcp_app.proto\x12\x13oak9.tython.gcp.app\x1a\x13shared/shared.proto\"C\n$AppEngineApplicationXFeatureSettings\x12\x1b\n\x13split_health_checks\x18\x01 \x01(\x08\"\x88\x01\n\x18\x41ppEngineApplicationXIap\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x18\n\x10oauth2_client_id\x18\x02 \x01(\t\x12\x1c\n\x14oauth2_client_secret\x18\x03 \x01(\t\x12#\n\x1boauth2_client_secret_sha256\x18\x04 \x01(\t\"?\n\x1d\x41ppEngineApplicationXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06update\x18\x02 \x01(\t\"\xa8\x05\n\x14\x41ppEngineApplication\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x13\n\x0b\x61uth_domain\x18\x02 \x01(\t\x12\x13\n\x0b\x63ode_bucket\x18\x03 \x01(\t\x12\x15\n\rdatabase_type\x18\x04 \x01(\t\x12\x16\n\x0e\x64\x65\x66\x61ult_bucket\x18\x05 \x01(\t\x12\x18\n\x10\x64\x65\x66\x61ult_hostname\x18\x06 \x01(\t\x12\x12\n\ngcr_domain\x18\x07 \x01(\t\x12\n\n\x02id\x18\x08 \x01(\t\x12\x13\n\x0blocation_id\x18\t \x01(\t\x12\x0c\n\x04name\x18\n \x01(\t\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x16\n\x0eserving_status\x18\x0c \x01(\t\x12Y\n\x11url_dispatch_rule\x18\r \x03(\x0b\x32>.oak9.tython.gcp.app.AppEngineApplication.UrlDispatchRuleEntry\x12S\n\x10\x66\x65\x61ture_settings\x18\x0e \x01(\x0b\x32\x39.oak9.tython.gcp.app.AppEngineApplicationXFeatureSettings\x12:\n\x03iap\x18\x0f \x01(\x0b\x32-.oak9.tython.gcp.app.AppEngineApplicationXIap\x12\x44\n\x08timeouts\x18\x10 \x01(\x0b\x32\x32.oak9.tython.gcp.app.AppEngineApplicationXTimeouts\x12\x37\n\rresource_info\x18\x11 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x36\n\x14UrlDispatchRuleEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"c\n2AppEngineApplicationUrlDispatchRulesXDispatchRules\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0f\n\x07service\x18\x03 \x01(\t\"_\n-AppEngineApplicationUrlDispatchRulesXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb3\x02\n$AppEngineApplicationUrlDispatchRules\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07project\x18\x02 \x01(\t\x12_\n\x0e\x64ispatch_rules\x18\x03 \x03(\x0b\x32G.oak9.tython.gcp.app.AppEngineApplicationUrlDispatchRulesXDispatchRules\x12T\n\x08timeouts\x18\x04 \x01(\x0b\x32\x42.oak9.tython.gcp.app.AppEngineApplicationUrlDispatchRulesXTimeouts\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x81\x01\n\"AppEngineDomainMappingXSslSettings\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\x12&\n\x1epending_managed_certificate_id\x18\x02 \x01(\t\x12\x1b\n\x13ssl_management_type\x18\x03 \x01(\t\"Q\n\x1f\x41ppEngineDomainMappingXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd7\x03\n\x16\x41ppEngineDomainMapping\x12\x13\n\x0b\x64omain_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x19\n\x11override_strategy\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12Z\n\x10resource_records\x18\x06 \x03(\x0b\x32@.oak9.tython.gcp.app.AppEngineDomainMapping.ResourceRecordsEntry\x12M\n\x0cssl_settings\x18\x07 \x01(\x0b\x32\x37.oak9.tython.gcp.app.AppEngineDomainMappingXSslSettings\x12\x46\n\x08timeouts\x18\x08 \x01(\x0b\x32\x34.oak9.tython.gcp.app.AppEngineDomainMappingXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x36\n\x14ResourceRecordsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"P\n\x1e\x41ppEngineFirewallRuleXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x81\x02\n\x15\x41ppEngineFirewallRule\x12\x0e\n\x06\x61\x63tion\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08priority\x18\x04 \x01(\x01\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x14\n\x0csource_range\x18\x06 \x01(\t\x12\x45\n\x08timeouts\x18\x07 \x01(\x0b\x32\x33.oak9.tython.gcp.app.AppEngineFirewallRuleXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x85\x01\n%AppEngineFlexibleAppVersionXApiConfig\x12\x18\n\x10\x61uth_fail_action\x18\x01 \x01(\t\x12\r\n\x05login\x18\x02 \x01(\t\x12\x0e\n\x06script\x18\x03 \x01(\t\x12\x16\n\x0esecurity_level\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\"|\n;AppEngineFlexibleAppVersionXAutomaticScalingXCpuUtilization\x12!\n\x19\x61ggregation_window_length\x18\x01 \x01(\t\x12\x1a\n\x12target_utilization\x18\x02 \x01(\x01\"\xd4\x01\n<AppEngineFlexibleAppVersionXAutomaticScalingXDiskUtilization\x12$\n\x1ctarget_read_bytes_per_second\x18\x01 \x01(\x01\x12\"\n\x1atarget_read_ops_per_second\x18\x02 \x01(\x01\x12%\n\x1dtarget_write_bytes_per_second\x18\x03 \x01(\x01\x12#\n\x1btarget_write_ops_per_second\x18\x04 \x01(\x01\"\xe5\x01\n?AppEngineFlexibleAppVersionXAutomaticScalingXNetworkUtilization\x12(\n target_received_bytes_per_second\x18\x01 \x01(\x01\x12*\n\"target_received_packets_per_second\x18\x02 \x01(\x01\x12$\n\x1ctarget_sent_bytes_per_second\x18\x03 \x01(\x01\x12&\n\x1etarget_sent_packets_per_second\x18\x04 \x01(\x01\"\x8e\x01\n?AppEngineFlexibleAppVersionXAutomaticScalingXRequestUtilization\x12\"\n\x1atarget_concurrent_requests\x18\x01 \x01(\x01\x12\'\n\x1ftarget_request_count_per_second\x18\x02 \x01(\t\"\xd3\x05\n,AppEngineFlexibleAppVersionXAutomaticScaling\x12\x18\n\x10\x63ool_down_period\x18\x01 \x01(\t\x12\x1f\n\x17max_concurrent_requests\x18\x02 \x01(\x01\x12\x1a\n\x12max_idle_instances\x18\x03 \x01(\x01\x12\x1b\n\x13max_pending_latency\x18\x04 \x01(\t\x12\x1b\n\x13max_total_instances\x18\x05 \x01(\x01\x12\x1a\n\x12min_idle_instances\x18\x06 \x01(\x01\x12\x1b\n\x13min_pending_latency\x18\x07 \x01(\t\x12\x1b\n\x13min_total_instances\x18\x08 \x01(\x01\x12i\n\x0f\x63pu_utilization\x18\t \x01(\x0b\x32P.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXAutomaticScalingXCpuUtilization\x12k\n\x10\x64isk_utilization\x18\n \x01(\x0b\x32Q.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXAutomaticScalingXDiskUtilization\x12q\n\x13network_utilization\x18\x0b \x01(\x0b\x32T.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXAutomaticScalingXNetworkUtilization\x12q\n\x13request_utilization\x18\x0c \x01(\x0b\x32T.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXAutomaticScalingXRequestUtilization\"n\n8AppEngineFlexibleAppVersionXDeploymentXCloudBuildOptions\x12\x15\n\rapp_yaml_path\x18\x01 \x01(\t\x12\x1b\n\x13\x63loud_build_timeout\x18\x02 \x01(\t\"A\n0AppEngineFlexibleAppVersionXDeploymentXContainer\x12\r\n\x05image\x18\x01 \x01(\t\"b\n,AppEngineFlexibleAppVersionXDeploymentXFiles\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08sha1_sum\x18\x02 \x01(\t\x12\x12\n\nsource_url\x18\x03 \x01(\t\"U\n*AppEngineFlexibleAppVersionXDeploymentXZip\x12\x13\n\x0b\x66iles_count\x18\x01 \x01(\x01\x12\x12\n\nsource_url\x18\x02 \x01(\t\"\x8e\x03\n&AppEngineFlexibleAppVersionXDeployment\x12j\n\x13\x63loud_build_options\x18\x01 \x01(\x0b\x32M.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXDeploymentXCloudBuildOptions\x12X\n\tcontainer\x18\x02 \x01(\x0b\x32\x45.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXDeploymentXContainer\x12P\n\x05\x66iles\x18\x03 \x03(\x0b\x32\x41.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXDeploymentXFiles\x12L\n\x03zip\x18\x04 \x01(\x0b\x32?.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXDeploymentXZip\"\x8c\x01\n/AppEngineFlexibleAppVersionXEndpointsApiService\x12\x11\n\tconfig_id\x18\x01 \x01(\t\x12\x1e\n\x16\x64isable_trace_sampling\x18\x02 \x01(\x08\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x18\n\x10rollout_strategy\x18\x04 \x01(\t\"7\n&AppEngineFlexibleAppVersionXEntrypoint\x12\r\n\x05shell\x18\x01 \x01(\t\"B\n+AppEngineFlexibleAppVersionXHandlersXScript\x12\x13\n\x0bscript_path\x18\x01 \x01(\t\"\xe1\x02\n0AppEngineFlexibleAppVersionXHandlersXStaticFiles\x12\x1c\n\x14\x61pplication_readable\x18\x01 \x01(\x08\x12\x12\n\nexpiration\x18\x02 \x01(\t\x12l\n\x0chttp_headers\x18\x03 \x03(\x0b\x32V.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXHandlersXStaticFiles.HttpHeadersEntry\x12\x11\n\tmime_type\x18\x04 \x01(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x1d\n\x15require_matching_file\x18\x06 \x01(\x08\x12\x19\n\x11upload_path_regex\x18\x07 \x01(\t\x1a\x32\n\x10HttpHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xce\x02\n$AppEngineFlexibleAppVersionXHandlers\x12\x18\n\x10\x61uth_fail_action\x18\x01 \x01(\t\x12\r\n\x05login\x18\x02 \x01(\t\x12#\n\x1bredirect_http_response_code\x18\x03 \x01(\t\x12\x16\n\x0esecurity_level\x18\x04 \x01(\t\x12\x11\n\turl_regex\x18\x05 \x01(\t\x12P\n\x06script\x18\x06 \x01(\x0b\x32@.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXHandlersXScript\x12[\n\x0cstatic_files\x18\x07 \x01(\x0b\x32\x45.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXHandlersXStaticFiles\"\xbd\x01\n)AppEngineFlexibleAppVersionXLivenessCheck\x12\x16\n\x0e\x63heck_interval\x18\x01 \x01(\t\x12\x19\n\x11\x66\x61ilure_threshold\x18\x02 \x01(\x01\x12\x0c\n\x04host\x18\x03 \x01(\t\x12\x15\n\rinitial_delay\x18\x04 \x01(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x19\n\x11success_threshold\x18\x06 \x01(\x01\x12\x0f\n\x07timeout\x18\x07 \x01(\t\">\n)AppEngineFlexibleAppVersionXManualScaling\x12\x11\n\tinstances\x18\x01 \x01(\x01\"\x90\x01\n#AppEngineFlexibleAppVersionXNetwork\x12\x17\n\x0f\x66orwarded_ports\x18\x01 \x03(\t\x12\x14\n\x0cinstance_tag\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x18\n\x10session_affinity\x18\x04 \x01(\x08\x12\x12\n\nsubnetwork\x18\x05 \x01(\t\"\xc2\x01\n*AppEngineFlexibleAppVersionXReadinessCheck\x12\x19\n\x11\x61pp_start_timeout\x18\x01 \x01(\t\x12\x16\n\x0e\x63heck_interval\x18\x02 \x01(\t\x12\x19\n\x11\x66\x61ilure_threshold\x18\x03 \x01(\x01\x12\x0c\n\x04host\x18\x04 \x01(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x19\n\x11success_threshold\x18\x06 \x01(\x01\x12\x0f\n\x07timeout\x18\x07 \x01(\t\"c\n-AppEngineFlexibleAppVersionXResourcesXVolumes\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07size_gb\x18\x02 \x01(\x01\x12\x13\n\x0bvolume_type\x18\x03 \x01(\t\"\xad\x01\n%AppEngineFlexibleAppVersionXResources\x12\x0b\n\x03\x63pu\x18\x01 \x01(\x01\x12\x0f\n\x07\x64isk_gb\x18\x02 \x01(\x01\x12\x11\n\tmemory_gb\x18\x03 \x01(\x01\x12S\n\x07volumes\x18\x04 \x03(\x0b\x32\x42.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXResourcesXVolumes\"V\n$AppEngineFlexibleAppVersionXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\">\n.AppEngineFlexibleAppVersionXVpcAccessConnector\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xc8\x0e\n\x1b\x41ppEngineFlexibleAppVersion\x12Y\n\rbeta_settings\x18\x01 \x03(\x0b\x32\x42.oak9.tython.gcp.app.AppEngineFlexibleAppVersion.BetaSettingsEntry\x12\x1a\n\x12\x64\x65\x66\x61ult_expiration\x18\x02 \x01(\t\x12!\n\x19\x64\x65lete_service_on_destroy\x18\x03 \x01(\x08\x12Y\n\renv_variables\x18\x04 \x03(\x0b\x32\x42.oak9.tython.gcp.app.AppEngineFlexibleAppVersion.EnvVariablesEntry\x12\n\n\x02id\x18\x05 \x01(\t\x12\x18\n\x10inbound_services\x18\x06 \x03(\t\x12\x16\n\x0einstance_class\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x1b\n\x13nobuild_files_regex\x18\t \x01(\t\x12\x17\n\x0fnoop_on_destroy\x18\n \x01(\x08\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x0f\n\x07runtime\x18\x0c \x01(\t\x12\x1b\n\x13runtime_api_version\x18\r \x01(\t\x12\x17\n\x0fruntime_channel\x18\x0e \x01(\t\x12$\n\x1cruntime_main_executable_path\x18\x0f \x01(\t\x12\x0f\n\x07service\x18\x10 \x01(\t\x12\x16\n\x0eserving_status\x18\x11 \x01(\t\x12\x12\n\nversion_id\x18\x12 \x01(\t\x12N\n\napi_config\x18\x13 \x01(\x0b\x32:.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXApiConfig\x12\\\n\x11\x61utomatic_scaling\x18\x14 \x01(\x0b\x32\x41.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXAutomaticScaling\x12O\n\ndeployment\x18\x15 \x01(\x0b\x32;.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXDeployment\x12\x63\n\x15\x65ndpoints_api_service\x18\x16 \x01(\x0b\x32\x44.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXEndpointsApiService\x12O\n\nentrypoint\x18\x17 \x01(\x0b\x32;.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXEntrypoint\x12K\n\x08handlers\x18\x18 \x03(\x0b\x32\x39.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXHandlers\x12V\n\x0eliveness_check\x18\x19 \x01(\x0b\x32>.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXLivenessCheck\x12V\n\x0emanual_scaling\x18\x1a \x01(\x0b\x32>.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXManualScaling\x12I\n\x07network\x18\x1b \x01(\x0b\x32\x38.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXNetwork\x12X\n\x0freadiness_check\x18\x1c \x01(\x0b\x32?.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXReadinessCheck\x12M\n\tresources\x18\x1d \x01(\x0b\x32:.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXResources\x12K\n\x08timeouts\x18\x1e \x01(\x0b\x32\x39.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXTimeouts\x12\x61\n\x14vpc_access_connector\x18\x1f \x01(\x0b\x32\x43.oak9.tython.gcp.app.AppEngineFlexibleAppVersionXVpcAccessConnector\x12\x37\n\rresource_info\x18  \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x33\n\x11\x42\x65taSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11\x45nvVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"R\n/AppEngineServiceNetworkSettingsXNetworkSettings\x12\x1f\n\x17ingress_traffic_allowed\x18\x01 \x01(\t\"Z\n(AppEngineServiceNetworkSettingsXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb9\x02\n\x1f\x41ppEngineServiceNetworkSettings\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07project\x18\x02 \x01(\t\x12\x0f\n\x07service\x18\x03 \x01(\t\x12^\n\x10network_settings\x18\x04 \x01(\x0b\x32\x44.oak9.tython.gcp.app.AppEngineServiceNetworkSettingsXNetworkSettings\x12O\n\x08timeouts\x18\x05 \x01(\x0b\x32=.oak9.tython.gcp.app.AppEngineServiceNetworkSettingsXTimeouts\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc9\x01\n\"AppEngineServiceSplitTrafficXSplit\x12]\n\x0b\x61llocations\x18\x01 \x03(\x0b\x32H.oak9.tython.gcp.app.AppEngineServiceSplitTrafficXSplit.AllocationsEntry\x12\x10\n\x08shard_by\x18\x02 \x01(\t\x1a\x32\n\x10\x41llocationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"W\n%AppEngineServiceSplitTrafficXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb4\x02\n\x1c\x41ppEngineServiceSplitTraffic\x12\n\n\x02id\x18\x01 \x01(\t\x12\x17\n\x0fmigrate_traffic\x18\x02 \x01(\x08\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\x12\x46\n\x05split\x18\x05 \x01(\x0b\x32\x37.oak9.tython.gcp.app.AppEngineServiceSplitTrafficXSplit\x12L\n\x08timeouts\x18\x06 \x01(\x0b\x32:.oak9.tython.gcp.app.AppEngineServiceSplitTrafficXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbd\x01\nFAppEngineStandardAppVersionXAutomaticScalingXStandardSchedulerSettings\x12\x15\n\rmax_instances\x18\x01 \x01(\x01\x12\x15\n\rmin_instances\x18\x02 \x01(\x01\x12\x1e\n\x16target_cpu_utilization\x18\x03 \x01(\x01\x12%\n\x1dtarget_throughput_utilization\x18\x04 \x01(\x01\"\xc4\x02\n,AppEngineStandardAppVersionXAutomaticScaling\x12\x1f\n\x17max_concurrent_requests\x18\x01 \x01(\x01\x12\x1a\n\x12max_idle_instances\x18\x02 \x01(\x01\x12\x1b\n\x13max_pending_latency\x18\x03 \x01(\t\x12\x1a\n\x12min_idle_instances\x18\x04 \x01(\x01\x12\x1b\n\x13min_pending_latency\x18\x05 \x01(\t\x12\x80\x01\n\x1bstandard_scheduler_settings\x18\x06 \x01(\x0b\x32[.oak9.tython.gcp.app.AppEngineStandardAppVersionXAutomaticScalingXStandardSchedulerSettings\"W\n(AppEngineStandardAppVersionXBasicScaling\x12\x14\n\x0cidle_timeout\x18\x01 \x01(\t\x12\x15\n\rmax_instances\x18\x02 \x01(\x01\"b\n,AppEngineStandardAppVersionXDeploymentXFiles\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08sha1_sum\x18\x02 \x01(\t\x12\x12\n\nsource_url\x18\x03 \x01(\t\"U\n*AppEngineStandardAppVersionXDeploymentXZip\x12\x13\n\x0b\x66iles_count\x18\x01 \x01(\x01\x12\x12\n\nsource_url\x18\x02 \x01(\t\"\xc8\x01\n&AppEngineStandardAppVersionXDeployment\x12P\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x41.oak9.tython.gcp.app.AppEngineStandardAppVersionXDeploymentXFiles\x12L\n\x03zip\x18\x02 \x01(\x0b\x32?.oak9.tython.gcp.app.AppEngineStandardAppVersionXDeploymentXZip\"7\n&AppEngineStandardAppVersionXEntrypoint\x12\r\n\x05shell\x18\x01 \x01(\t\"B\n+AppEngineStandardAppVersionXHandlersXScript\x12\x13\n\x0bscript_path\x18\x01 \x01(\t\"\xe1\x02\n0AppEngineStandardAppVersionXHandlersXStaticFiles\x12\x1c\n\x14\x61pplication_readable\x18\x01 \x01(\x08\x12\x12\n\nexpiration\x18\x02 \x01(\t\x12l\n\x0chttp_headers\x18\x03 \x03(\x0b\x32V.oak9.tython.gcp.app.AppEngineStandardAppVersionXHandlersXStaticFiles.HttpHeadersEntry\x12\x11\n\tmime_type\x18\x04 \x01(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x1d\n\x15require_matching_file\x18\x06 \x01(\x08\x12\x19\n\x11upload_path_regex\x18\x07 \x01(\t\x1a\x32\n\x10HttpHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xce\x02\n$AppEngineStandardAppVersionXHandlers\x12\x18\n\x10\x61uth_fail_action\x18\x01 \x01(\t\x12\r\n\x05login\x18\x02 \x01(\t\x12#\n\x1bredirect_http_response_code\x18\x03 \x01(\t\x12\x16\n\x0esecurity_level\x18\x04 \x01(\t\x12\x11\n\turl_regex\x18\x05 \x01(\t\x12P\n\x06script\x18\x06 \x01(\x0b\x32@.oak9.tython.gcp.app.AppEngineStandardAppVersionXHandlersXScript\x12[\n\x0cstatic_files\x18\x07 \x01(\x0b\x32\x45.oak9.tython.gcp.app.AppEngineStandardAppVersionXHandlersXStaticFiles\"F\n%AppEngineStandardAppVersionXLibraries\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\">\n)AppEngineStandardAppVersionXManualScaling\x12\x11\n\tinstances\x18\x01 \x01(\x01\"V\n$AppEngineStandardAppVersionXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\">\n.AppEngineStandardAppVersionXVpcAccessConnector\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xe0\t\n\x1b\x41ppEngineStandardAppVersion\x12!\n\x19\x64\x65lete_service_on_destroy\x18\x01 \x01(\x08\x12Y\n\renv_variables\x18\x02 \x03(\x0b\x32\x42.oak9.tython.gcp.app.AppEngineStandardAppVersion.EnvVariablesEntry\x12\n\n\x02id\x18\x03 \x01(\t\x12\x18\n\x10inbound_services\x18\x04 \x03(\t\x12\x16\n\x0einstance_class\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x17\n\x0fnoop_on_destroy\x18\x07 \x01(\x08\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x0f\n\x07runtime\x18\t \x01(\t\x12\x1b\n\x13runtime_api_version\x18\n \x01(\t\x12\x0f\n\x07service\x18\x0b \x01(\t\x12\x12\n\nthreadsafe\x18\x0c \x01(\x08\x12\x12\n\nversion_id\x18\r \x01(\t\x12\\\n\x11\x61utomatic_scaling\x18\x0e \x01(\x0b\x32\x41.oak9.tython.gcp.app.AppEngineStandardAppVersionXAutomaticScaling\x12T\n\rbasic_scaling\x18\x0f \x01(\x0b\x32=.oak9.tython.gcp.app.AppEngineStandardAppVersionXBasicScaling\x12O\n\ndeployment\x18\x10 \x01(\x0b\x32;.oak9.tython.gcp.app.AppEngineStandardAppVersionXDeployment\x12O\n\nentrypoint\x18\x11 \x01(\x0b\x32;.oak9.tython.gcp.app.AppEngineStandardAppVersionXEntrypoint\x12K\n\x08handlers\x18\x12 \x03(\x0b\x32\x39.oak9.tython.gcp.app.AppEngineStandardAppVersionXHandlers\x12M\n\tlibraries\x18\x13 \x03(\x0b\x32:.oak9.tython.gcp.app.AppEngineStandardAppVersionXLibraries\x12V\n\x0emanual_scaling\x18\x14 \x01(\x0b\x32>.oak9.tython.gcp.app.AppEngineStandardAppVersionXManualScaling\x12K\n\x08timeouts\x18\x15 \x01(\x0b\x32\x39.oak9.tython.gcp.app.AppEngineStandardAppVersionXTimeouts\x12\x61\n\x14vpc_access_connector\x18\x16 \x01(\x0b\x32\x43.oak9.tython.gcp.app.AppEngineStandardAppVersionXVpcAccessConnector\x12\x37\n\rresource_info\x18\x17 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x33\n\x11\x45nvVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_app_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APPENGINEAPPLICATION_URLDISPATCHRULEENTRY._options = None
  _APPENGINEAPPLICATION_URLDISPATCHRULEENTRY._serialized_options = b'8\001'
  _APPENGINEDOMAINMAPPING_RESOURCERECORDSENTRY._options = None
  _APPENGINEDOMAINMAPPING_RESOURCERECORDSENTRY._serialized_options = b'8\001'
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERSXSTATICFILES_HTTPHEADERSENTRY._options = None
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERSXSTATICFILES_HTTPHEADERSENTRY._serialized_options = b'8\001'
  _APPENGINEFLEXIBLEAPPVERSION_BETASETTINGSENTRY._options = None
  _APPENGINEFLEXIBLEAPPVERSION_BETASETTINGSENTRY._serialized_options = b'8\001'
  _APPENGINEFLEXIBLEAPPVERSION_ENVVARIABLESENTRY._options = None
  _APPENGINEFLEXIBLEAPPVERSION_ENVVARIABLESENTRY._serialized_options = b'8\001'
  _APPENGINESERVICESPLITTRAFFICXSPLIT_ALLOCATIONSENTRY._options = None
  _APPENGINESERVICESPLITTRAFFICXSPLIT_ALLOCATIONSENTRY._serialized_options = b'8\001'
  _APPENGINESTANDARDAPPVERSIONXHANDLERSXSTATICFILES_HTTPHEADERSENTRY._options = None
  _APPENGINESTANDARDAPPVERSIONXHANDLERSXSTATICFILES_HTTPHEADERSENTRY._serialized_options = b'8\001'
  _APPENGINESTANDARDAPPVERSION_ENVVARIABLESENTRY._options = None
  _APPENGINESTANDARDAPPVERSION_ENVVARIABLESENTRY._serialized_options = b'8\001'
  _APPENGINEAPPLICATIONXFEATURESETTINGS._serialized_start=63
  _APPENGINEAPPLICATIONXFEATURESETTINGS._serialized_end=130
  _APPENGINEAPPLICATIONXIAP._serialized_start=133
  _APPENGINEAPPLICATIONXIAP._serialized_end=269
  _APPENGINEAPPLICATIONXTIMEOUTS._serialized_start=271
  _APPENGINEAPPLICATIONXTIMEOUTS._serialized_end=334
  _APPENGINEAPPLICATION._serialized_start=337
  _APPENGINEAPPLICATION._serialized_end=1017
  _APPENGINEAPPLICATION_URLDISPATCHRULEENTRY._serialized_start=963
  _APPENGINEAPPLICATION_URLDISPATCHRULEENTRY._serialized_end=1017
  _APPENGINEAPPLICATIONURLDISPATCHRULESXDISPATCHRULES._serialized_start=1019
  _APPENGINEAPPLICATIONURLDISPATCHRULESXDISPATCHRULES._serialized_end=1118
  _APPENGINEAPPLICATIONURLDISPATCHRULESXTIMEOUTS._serialized_start=1120
  _APPENGINEAPPLICATIONURLDISPATCHRULESXTIMEOUTS._serialized_end=1215
  _APPENGINEAPPLICATIONURLDISPATCHRULES._serialized_start=1218
  _APPENGINEAPPLICATIONURLDISPATCHRULES._serialized_end=1525
  _APPENGINEDOMAINMAPPINGXSSLSETTINGS._serialized_start=1528
  _APPENGINEDOMAINMAPPINGXSSLSETTINGS._serialized_end=1657
  _APPENGINEDOMAINMAPPINGXTIMEOUTS._serialized_start=1659
  _APPENGINEDOMAINMAPPINGXTIMEOUTS._serialized_end=1740
  _APPENGINEDOMAINMAPPING._serialized_start=1743
  _APPENGINEDOMAINMAPPING._serialized_end=2214
  _APPENGINEDOMAINMAPPING_RESOURCERECORDSENTRY._serialized_start=2160
  _APPENGINEDOMAINMAPPING_RESOURCERECORDSENTRY._serialized_end=2214
  _APPENGINEFIREWALLRULEXTIMEOUTS._serialized_start=2216
  _APPENGINEFIREWALLRULEXTIMEOUTS._serialized_end=2296
  _APPENGINEFIREWALLRULE._serialized_start=2299
  _APPENGINEFIREWALLRULE._serialized_end=2556
  _APPENGINEFLEXIBLEAPPVERSIONXAPICONFIG._serialized_start=2559
  _APPENGINEFLEXIBLEAPPVERSIONXAPICONFIG._serialized_end=2692
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALINGXCPUUTILIZATION._serialized_start=2694
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALINGXCPUUTILIZATION._serialized_end=2818
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALINGXDISKUTILIZATION._serialized_start=2821
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALINGXDISKUTILIZATION._serialized_end=3033
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALINGXNETWORKUTILIZATION._serialized_start=3036
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALINGXNETWORKUTILIZATION._serialized_end=3265
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALINGXREQUESTUTILIZATION._serialized_start=3268
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALINGXREQUESTUTILIZATION._serialized_end=3410
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALING._serialized_start=3413
  _APPENGINEFLEXIBLEAPPVERSIONXAUTOMATICSCALING._serialized_end=4136
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENTXCLOUDBUILDOPTIONS._serialized_start=4138
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENTXCLOUDBUILDOPTIONS._serialized_end=4248
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENTXCONTAINER._serialized_start=4250
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENTXCONTAINER._serialized_end=4315
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENTXFILES._serialized_start=4317
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENTXFILES._serialized_end=4415
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENTXZIP._serialized_start=4417
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENTXZIP._serialized_end=4502
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENT._serialized_start=4505
  _APPENGINEFLEXIBLEAPPVERSIONXDEPLOYMENT._serialized_end=4903
  _APPENGINEFLEXIBLEAPPVERSIONXENDPOINTSAPISERVICE._serialized_start=4906
  _APPENGINEFLEXIBLEAPPVERSIONXENDPOINTSAPISERVICE._serialized_end=5046
  _APPENGINEFLEXIBLEAPPVERSIONXENTRYPOINT._serialized_start=5048
  _APPENGINEFLEXIBLEAPPVERSIONXENTRYPOINT._serialized_end=5103
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERSXSCRIPT._serialized_start=5105
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERSXSCRIPT._serialized_end=5171
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERSXSTATICFILES._serialized_start=5174
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERSXSTATICFILES._serialized_end=5527
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERSXSTATICFILES_HTTPHEADERSENTRY._serialized_start=5477
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERSXSTATICFILES_HTTPHEADERSENTRY._serialized_end=5527
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERS._serialized_start=5530
  _APPENGINEFLEXIBLEAPPVERSIONXHANDLERS._serialized_end=5864
  _APPENGINEFLEXIBLEAPPVERSIONXLIVENESSCHECK._serialized_start=5867
  _APPENGINEFLEXIBLEAPPVERSIONXLIVENESSCHECK._serialized_end=6056
  _APPENGINEFLEXIBLEAPPVERSIONXMANUALSCALING._serialized_start=6058
  _APPENGINEFLEXIBLEAPPVERSIONXMANUALSCALING._serialized_end=6120
  _APPENGINEFLEXIBLEAPPVERSIONXNETWORK._serialized_start=6123
  _APPENGINEFLEXIBLEAPPVERSIONXNETWORK._serialized_end=6267
  _APPENGINEFLEXIBLEAPPVERSIONXREADINESSCHECK._serialized_start=6270
  _APPENGINEFLEXIBLEAPPVERSIONXREADINESSCHECK._serialized_end=6464
  _APPENGINEFLEXIBLEAPPVERSIONXRESOURCESXVOLUMES._serialized_start=6466
  _APPENGINEFLEXIBLEAPPVERSIONXRESOURCESXVOLUMES._serialized_end=6565
  _APPENGINEFLEXIBLEAPPVERSIONXRESOURCES._serialized_start=6568
  _APPENGINEFLEXIBLEAPPVERSIONXRESOURCES._serialized_end=6741
  _APPENGINEFLEXIBLEAPPVERSIONXTIMEOUTS._serialized_start=6743
  _APPENGINEFLEXIBLEAPPVERSIONXTIMEOUTS._serialized_end=6829
  _APPENGINEFLEXIBLEAPPVERSIONXVPCACCESSCONNECTOR._serialized_start=6831
  _APPENGINEFLEXIBLEAPPVERSIONXVPCACCESSCONNECTOR._serialized_end=6893
  _APPENGINEFLEXIBLEAPPVERSION._serialized_start=6896
  _APPENGINEFLEXIBLEAPPVERSION._serialized_end=8760
  _APPENGINEFLEXIBLEAPPVERSION_BETASETTINGSENTRY._serialized_start=8656
  _APPENGINEFLEXIBLEAPPVERSION_BETASETTINGSENTRY._serialized_end=8707
  _APPENGINEFLEXIBLEAPPVERSION_ENVVARIABLESENTRY._serialized_start=8709
  _APPENGINEFLEXIBLEAPPVERSION_ENVVARIABLESENTRY._serialized_end=8760
  _APPENGINESERVICENETWORKSETTINGSXNETWORKSETTINGS._serialized_start=8762
  _APPENGINESERVICENETWORKSETTINGSXNETWORKSETTINGS._serialized_end=8844
  _APPENGINESERVICENETWORKSETTINGSXTIMEOUTS._serialized_start=8846
  _APPENGINESERVICENETWORKSETTINGSXTIMEOUTS._serialized_end=8936
  _APPENGINESERVICENETWORKSETTINGS._serialized_start=8939
  _APPENGINESERVICENETWORKSETTINGS._serialized_end=9252
  _APPENGINESERVICESPLITTRAFFICXSPLIT._serialized_start=9255
  _APPENGINESERVICESPLITTRAFFICXSPLIT._serialized_end=9456
  _APPENGINESERVICESPLITTRAFFICXSPLIT_ALLOCATIONSENTRY._serialized_start=9406
  _APPENGINESERVICESPLITTRAFFICXSPLIT_ALLOCATIONSENTRY._serialized_end=9456
  _APPENGINESERVICESPLITTRAFFICXTIMEOUTS._serialized_start=9458
  _APPENGINESERVICESPLITTRAFFICXTIMEOUTS._serialized_end=9545
  _APPENGINESERVICESPLITTRAFFIC._serialized_start=9548
  _APPENGINESERVICESPLITTRAFFIC._serialized_end=9856
  _APPENGINESTANDARDAPPVERSIONXAUTOMATICSCALINGXSTANDARDSCHEDULERSETTINGS._serialized_start=9859
  _APPENGINESTANDARDAPPVERSIONXAUTOMATICSCALINGXSTANDARDSCHEDULERSETTINGS._serialized_end=10048
  _APPENGINESTANDARDAPPVERSIONXAUTOMATICSCALING._serialized_start=10051
  _APPENGINESTANDARDAPPVERSIONXAUTOMATICSCALING._serialized_end=10375
  _APPENGINESTANDARDAPPVERSIONXBASICSCALING._serialized_start=10377
  _APPENGINESTANDARDAPPVERSIONXBASICSCALING._serialized_end=10464
  _APPENGINESTANDARDAPPVERSIONXDEPLOYMENTXFILES._serialized_start=10466
  _APPENGINESTANDARDAPPVERSIONXDEPLOYMENTXFILES._serialized_end=10564
  _APPENGINESTANDARDAPPVERSIONXDEPLOYMENTXZIP._serialized_start=10566
  _APPENGINESTANDARDAPPVERSIONXDEPLOYMENTXZIP._serialized_end=10651
  _APPENGINESTANDARDAPPVERSIONXDEPLOYMENT._serialized_start=10654
  _APPENGINESTANDARDAPPVERSIONXDEPLOYMENT._serialized_end=10854
  _APPENGINESTANDARDAPPVERSIONXENTRYPOINT._serialized_start=10856
  _APPENGINESTANDARDAPPVERSIONXENTRYPOINT._serialized_end=10911
  _APPENGINESTANDARDAPPVERSIONXHANDLERSXSCRIPT._serialized_start=10913
  _APPENGINESTANDARDAPPVERSIONXHANDLERSXSCRIPT._serialized_end=10979
  _APPENGINESTANDARDAPPVERSIONXHANDLERSXSTATICFILES._serialized_start=10982
  _APPENGINESTANDARDAPPVERSIONXHANDLERSXSTATICFILES._serialized_end=11335
  _APPENGINESTANDARDAPPVERSIONXHANDLERSXSTATICFILES_HTTPHEADERSENTRY._serialized_start=5477
  _APPENGINESTANDARDAPPVERSIONXHANDLERSXSTATICFILES_HTTPHEADERSENTRY._serialized_end=5527
  _APPENGINESTANDARDAPPVERSIONXHANDLERS._serialized_start=11338
  _APPENGINESTANDARDAPPVERSIONXHANDLERS._serialized_end=11672
  _APPENGINESTANDARDAPPVERSIONXLIBRARIES._serialized_start=11674
  _APPENGINESTANDARDAPPVERSIONXLIBRARIES._serialized_end=11744
  _APPENGINESTANDARDAPPVERSIONXMANUALSCALING._serialized_start=11746
  _APPENGINESTANDARDAPPVERSIONXMANUALSCALING._serialized_end=11808
  _APPENGINESTANDARDAPPVERSIONXTIMEOUTS._serialized_start=11810
  _APPENGINESTANDARDAPPVERSIONXTIMEOUTS._serialized_end=11896
  _APPENGINESTANDARDAPPVERSIONXVPCACCESSCONNECTOR._serialized_start=11898
  _APPENGINESTANDARDAPPVERSIONXVPCACCESSCONNECTOR._serialized_end=11960
  _APPENGINESTANDARDAPPVERSION._serialized_start=11963
  _APPENGINESTANDARDAPPVERSION._serialized_end=13211
  _APPENGINESTANDARDAPPVERSION_ENVVARIABLESENTRY._serialized_start=8709
  _APPENGINESTANDARDAPPVERSION_ENVVARIABLESENTRY._serialized_end=8760
# @@protoc_insertion_point(module_scope)
